@@ -1,35 +1,18 @@
-use std::collections::hash_map::DefaultHasher;
 use std::hash::{Hash, Hasher};
 
 use ruff_cache::{CacheKey, CacheKeyHasher};
 use ruff_macros::CacheKey;
 
-#[derive(CacheKey, Hash)]
-struct UnitStruct;
-
-#[derive(CacheKey, Hash)]
-struct NamedFieldsStruct {
-    a: String,
-    b: String,
-}
-
-#[derive(CacheKey, Hash)]
-struct UnnamedFieldsStruct(String, String);
-
-#[derive(CacheKey, Hash)]
-enum Enum {
-    Unit,
-    UnnamedFields(String, String),
-    NamedFields { a: String, b: String },
-}
-
 #[test]
 fn unit_struct_cache_key() {
+    #[derive(CacheKey, Hash)]
+    struct UnitStruct;
+
     let mut key = CacheKeyHasher::new();
 
     UnitStruct.cache_key(&mut key);
 
-    let mut hash = DefaultHasher::new();
+    let mut hash = CacheKeyHasher::new();
     UnitStruct.hash(&mut hash);
 
     assert_eq!(hash.finish(), key.finish());
@@ -37,6 +20,12 @@ fn unit_struct_cache_key() {
 
 #[test]
 fn named_field_struct() {
+    #[derive(CacheKey, Hash)]
+    struct NamedFieldsStruct {
+        a: String,
+        b: String,
+    }
+
     let mut key = CacheKeyHasher::new();
 
     let named_fields = NamedFieldsStruct {
@@ -46,7 +35,38 @@ fn named_field_struct() {
 
     named_fields.cache_key(&mut key);
 
-    let mut hash = DefaultHasher::new();
+    let mut hash = CacheKeyHasher::new();
+    named_fields.hash(&mut hash);
+
+    assert_eq!(hash.finish(), key.finish());
+}
+
+#[test]
+fn struct_ignored_fields() {
+    #[derive(CacheKey)]
+    struct NamedFieldsStruct {
+        a: String,
+        #[cache_key(ignore)]
+        #[allow(unused)]
+        b: String,
+    }
+
+    impl Hash for NamedFieldsStruct {
+        fn hash<H: Hasher>(&self, state: &mut H) {
+            self.a.hash(state);
+        }
+    }
+
+    let mut key = CacheKeyHasher::new();
+
+    let named_fields = NamedFieldsStruct {
+        a: "Hello".into(),
+        b: "World".into(),
+    };
+
+    named_fields.cache_key(&mut key);
+
+    let mut hash = CacheKeyHasher::new();
     named_fields.hash(&mut hash);
 
     assert_eq!(hash.finish(), key.finish());
@@ -54,18 +74,28 @@ fn named_field_struct() {
 
 #[test]
 fn unnamed_field_struct() {
+    #[derive(CacheKey, Hash)]
+    struct UnnamedFieldsStruct(String, String);
+
     let mut key = CacheKeyHasher::new();
 
     let unnamed_fields = UnnamedFieldsStruct("Hello".into(), "World".into());
 
     unnamed_fields.cache_key(&mut key);
 
-    let mut hash = DefaultHasher::new();
+    let mut hash = CacheKeyHasher::new();
     unnamed_fields.hash(&mut hash);
 
     assert_eq!(hash.finish(), key.finish());
 }
 
+#[derive(CacheKey, Hash)]
+enum Enum {
+    Unit,
+    UnnamedFields(String, String),
+    NamedFields { a: String, b: String },
+}
+
 #[test]
 fn enum_unit_variant() {
     let mut key = CacheKeyHasher::new();
@@ -73,7 +103,7 @@ fn enum_unit_variant() {
     let variant = Enum::Unit;
     variant.cache_key(&mut key);
 
-    let mut hash = DefaultHasher::new();
+    let mut hash = CacheKeyHasher::new();
     variant.hash(&mut hash);
 
     assert_eq!(hash.finish(), key.finish());
@@ -89,7 +119,7 @@ fn enum_named_fields_variant() {
     };
     variant.cache_key(&mut key);
 
-    let mut hash = DefaultHasher::new();
+    let mut hash = CacheKeyHasher::new();
     variant.hash(&mut hash);
 
     assert_eq!(hash.finish(), key.finish());
@@ -102,7 +132,7 @@ fn enum_unnamed_fields_variant() {
     let variant = Enum::UnnamedFields("Hello".to_string(), "World".to_string());
     variant.cache_key(&mut key);
 
-    let mut hash = DefaultHasher::new();
+    let mut hash = CacheKeyHasher::new();
     variant.hash(&mut hash);
 
     assert_eq!(hash.finish(), key.finish());
