@@ -4,15 +4,15 @@ use clap::{command, Parser};
 use regex::Regex;
 use rustc_hash::FxHashMap;
 
-use ruff::line_width::LineLength;
-use ruff::logging::LogLevel;
-use ruff::registry::Rule;
-use ruff::settings::types::{
+use ruff_linter::line_width::LineLength;
+use ruff_linter::logging::LogLevel;
+use ruff_linter::registry::Rule;
+use ruff_linter::settings::types::{
     FilePattern, PatternPrefixPair, PerFileIgnore, PreviewMode, PythonVersion, SerializationFormat,
 };
-use ruff::{RuleSelector, RuleSelectorParser};
+use ruff_linter::{RuleParser, RuleSelector, RuleSelectorParser};
 use ruff_workspace::configuration::{Configuration, RuleSelection};
-use ruff_workspace::resolver::ConfigProcessor;
+use ruff_workspace::resolver::ConfigurationTransformer;
 
 #[derive(Debug, Parser)]
 #[command(
@@ -39,7 +39,7 @@ pub enum Command {
     #[command(group = clap::ArgGroup::new("selector").multiple(false).required(true))]
     Rule {
         /// Rule to explain
-        #[arg(value_parser=Rule::from_code, group = "selector")]
+        #[arg(value_parser=RuleParser, group = "selector", hide_possible_values = true)]
         rule: Option<Rule>,
 
         /// Explain all rules
@@ -77,16 +77,19 @@ pub struct CheckCommand {
     /// List of files or directories to check.
     pub files: Vec<PathBuf>,
     /// Attempt to automatically fix lint violations.
+    /// Use `--no-fix` to disable.
     #[arg(long, overrides_with("no_fix"))]
     fix: bool,
     #[clap(long, overrides_with("fix"), hide = true)]
     no_fix: bool,
     /// Show violations with source code.
+    /// Use `--no-show-source` to disable.
     #[arg(long, overrides_with("no_show_source"))]
     show_source: bool,
     #[clap(long, overrides_with("show_source"), hide = true)]
     no_show_source: bool,
     /// Show an enumeration of all autofixed lint violations.
+    /// Use `--no-show-fixes` to disable.
     #[arg(long, overrides_with("no_show_fixes"))]
     show_fixes: bool,
     #[clap(long, overrides_with("show_fixes"), hide = true)]
@@ -98,6 +101,7 @@ pub struct CheckCommand {
     #[arg(short, long)]
     pub watch: bool,
     /// Fix any fixable lint violations, but don't report on leftover violations. Implies `--fix`.
+    /// Use `--no-fix-only` to disable.
     #[arg(long, overrides_with("no_fix_only"))]
     fix_only: bool,
     #[clap(long, overrides_with("fix_only"), hide = true)]
@@ -105,9 +109,21 @@ pub struct CheckCommand {
     /// Ignore any `# noqa` comments.
     #[arg(long)]
     ignore_noqa: bool,
-    /// Output serialization format for violations.
-    #[arg(long, value_enum, env = "RUFF_FORMAT")]
+
+    /// Output serialization format for violations. (Deprecated: Use `--output-format` instead).
+    #[arg(
+        long,
+        value_enum,
+        env = "RUFF_FORMAT",
+        conflicts_with = "output_format",
+        hide = true
+    )]
     pub format: Option<SerializationFormat>,
+
+    /// Output serialization format for violations.
+    #[arg(long, value_enum, env = "RUFF_OUTPUT_FORMAT")]
+    pub output_format: Option<SerializationFormat>,
+
     /// Specify file to write the linter output to (default: stdout).
     #[arg(short, long)]
     pub output_file: Option<PathBuf>,
@@ -115,6 +131,7 @@ pub struct CheckCommand {
     #[arg(long, value_enum)]
     pub target_version: Option<PythonVersion>,
     /// Enable preview mode; checks will include unstable rules and fixes.
+    /// Use `--no-preview` to disable.
     #[arg(long, overrides_with("no_preview"))]
     preview: bool,
     #[clap(long, overrides_with("preview"), hide = true)]
@@ -226,6 +243,7 @@ pub struct CheckCommand {
     )]
     pub extend_unfixable: Option<Vec<RuleSelector>>,
     /// Respect file exclusions via `.gitignore` and other standard ignore files.
+    /// Use `--no-respect-gitignore` to disable.
     #[arg(
         long,
         overrides_with("no_respect_gitignore"),
@@ -235,6 +253,7 @@ pub struct CheckCommand {
     #[clap(long, overrides_with("respect_gitignore"), hide = true)]
     no_respect_gitignore: bool,
     /// Enforce exclusions, even for paths passed to Ruff directly on the command-line.
+    /// Use `--no-force-exclude` to disable.
     #[arg(
         long,
         overrides_with("no_force_exclude"),
@@ -341,6 +360,7 @@ pub struct FormatCommand {
     #[arg(long, conflicts_with = "isolated")]
     pub config: Option<PathBuf>,
     /// Respect file exclusions via `.gitignore` and other standard ignore files.
+    /// Use `--no-respect-gitignore` to disable.
     #[arg(
         long,
         overrides_with("no_respect_gitignore"),
@@ -350,6 +370,7 @@ pub struct FormatCommand {
     #[clap(long, overrides_with("respect_gitignore"), hide = true)]
     no_respect_gitignore: bool,
     /// Enforce exclusions, even for paths passed to Ruff directly on the command-line.
+    /// Use `--no-force-exclude` to disable.
     #[arg(
         long,
         overrides_with("no_force_exclude"),
@@ -369,6 +390,7 @@ pub struct FormatCommand {
     pub stdin_filename: Option<PathBuf>,
 
     /// Enable preview mode; checks will include unstable rules and fixes.
+    /// Use `--no-preview` to disable.
     #[arg(long, overrides_with("no_preview"), hide = true)]
     preview: bool,
     #[clap(long, overrides_with("preview"), hide = true)]
@@ -430,7 +452,7 @@ impl From<&LogLevelArgs> for LogLevel {
 impl CheckCommand {
     /// Partition the CLI into command-line arguments and configuration
     /// overrides.
-    pub fn partition(self) -> (CheckArguments, Overrides) {
+    pub fn partition(self) -> (CheckArguments, CliOverrides) {
         (
             CheckArguments {
                 add_noqa: self.add_noqa,
@@ -450,7 +472,7 @@ impl CheckCommand {
                 stdin_filename: self.stdin_filename,
                 watch: self.watch,
             },
-            Overrides {
+            CliOverrides {
                 dummy_variable_rgx: self.dummy_variable_rgx,
                 exclude: self.exclude,
                 extend_exclude: self.extend_exclude,
@@ -476,7 +498,7 @@ impl CheckCommand {
                 fix: resolve_bool_arg(self.fix, self.no_fix),
                 fix_only: resolve_bool_arg(self.fix_only, self.no_fix_only),
                 force_exclude: resolve_bool_arg(self.force_exclude, self.no_force_exclude),
-                format: self.format,
+                output_format: self.output_format.or(self.format),
                 show_fixes: resolve_bool_arg(self.show_fixes, self.no_show_fixes),
             },
         )
@@ -486,7 +508,7 @@ impl CheckCommand {
 impl FormatCommand {
     /// Partition the CLI into command-line arguments and configuration
     /// overrides.
-    pub fn partition(self) -> (FormatArguments, Overrides) {
+    pub fn partition(self) -> (FormatArguments, CliOverrides) {
         (
             FormatArguments {
                 check: self.check,
@@ -495,7 +517,7 @@ impl FormatCommand {
                 isolated: self.isolated,
                 stdin_filename: self.stdin_filename,
             },
-            Overrides {
+            CliOverrides {
                 line_length: self.line_length,
                 respect_gitignore: resolve_bool_arg(
                     self.respect_gitignore,
@@ -504,7 +526,7 @@ impl FormatCommand {
                 preview: resolve_bool_arg(self.preview, self.no_preview).map(PreviewMode::from),
                 force_exclude: resolve_bool_arg(self.force_exclude, self.no_force_exclude),
                 // Unsupported on the formatter CLI, but required on `Overrides`.
-                ..Overrides::default()
+                ..CliOverrides::default()
             },
         )
     }
@@ -555,7 +577,7 @@ pub struct FormatArguments {
 /// CLI settings that function as configuration overrides.
 #[derive(Clone, Default)]
 #[allow(clippy::struct_excessive_bools)]
-pub struct Overrides {
+pub struct CliOverrides {
     pub dummy_variable_rgx: Option<Regex>,
     pub exclude: Option<Vec<FilePattern>>,
     pub extend_exclude: Option<Vec<FilePattern>>,
@@ -578,12 +600,12 @@ pub struct Overrides {
     pub fix: Option<bool>,
     pub fix_only: Option<bool>,
     pub force_exclude: Option<bool>,
-    pub format: Option<SerializationFormat>,
+    pub output_format: Option<SerializationFormat>,
     pub show_fixes: Option<bool>,
 }
 
-impl ConfigProcessor for Overrides {
-    fn process_config(&self, config: &mut Configuration) {
+impl ConfigurationTransformer for CliOverrides {
+    fn transform(&self, mut config: Configuration) -> Configuration {
         if let Some(cache_dir) = &self.cache_dir {
             config.cache_dir = Some(cache_dir.clone());
         }
@@ -622,8 +644,8 @@ impl ConfigProcessor for Overrides {
                 .collect(),
             extend_fixable: self.extend_fixable.clone().unwrap_or_default(),
         });
-        if let Some(format) = &self.format {
-            config.format = Some(*format);
+        if let Some(output_format) = &self.output_format {
+            config.output_format = Some(*output_format);
         }
         if let Some(force_exclude) = &self.force_exclude {
             config.force_exclude = Some(*force_exclude);
@@ -649,6 +671,8 @@ impl ConfigProcessor for Overrides {
         if let Some(target_version) = &self.target_version {
             config.target_version = Some(*target_version);
         }
+
+        config
     }
 }
 
