@@ -2,11 +2,11 @@ use std::path::Path;
 
 use anyhow::Result;
 
-use ruff::packaging;
-use ruff::settings::flags;
+use ruff_linter::packaging;
+use ruff_linter::settings::flags;
 use ruff_workspace::resolver::{python_file_at_path, PyprojectConfig};
 
-use crate::args::Overrides;
+use crate::args::CliOverrides;
 use crate::diagnostics::{lint_stdin, Diagnostics};
 use crate::stdin::read_from_stdin;
 
@@ -14,7 +14,7 @@ use crate::stdin::read_from_stdin;
 pub(crate) fn check_stdin(
     filename: Option<&Path>,
     pyproject_config: &PyprojectConfig,
-    overrides: &Overrides,
+    overrides: &CliOverrides,
     noqa: flags::Noqa,
     autofix: flags::FixMode,
 ) -> Result<Diagnostics> {
@@ -24,14 +24,14 @@ pub(crate) fn check_stdin(
         }
     }
     let package_root = filename.and_then(Path::parent).and_then(|path| {
-        packaging::detect_package_root(path, &pyproject_config.settings.lib.namespace_packages)
+        packaging::detect_package_root(path, &pyproject_config.settings.linter.namespace_packages)
     });
     let stdin = read_from_stdin()?;
     let mut diagnostics = lint_stdin(
         filename,
         package_root,
         stdin,
-        &pyproject_config.settings.lib,
+        &pyproject_config.settings,
         noqa,
         autofix,
     )?;
