@@ -6,9 +6,9 @@ use colored::Colorize;
 use path_absolutize::path_dedot;
 use walkdir::WalkDir;
 
-use ruff::fs;
-use ruff::logging::LogLevel;
 use ruff_cache::CACHE_DIR_NAME;
+use ruff_linter::fs;
+use ruff_linter::logging::LogLevel;
 
 /// Clear any caches in the current directory or any subdirectories.
 pub(crate) fn clean(level: LogLevel) -> Result<()> {
