@@ -1,9 +1,11 @@
 pub(crate) mod add_noqa;
+pub(crate) mod check;
+pub(crate) mod check_stdin;
 pub(crate) mod clean;
 pub(crate) mod config;
+pub(crate) mod format;
+pub(crate) mod format_stdin;
 pub(crate) mod linter;
 pub(crate) mod rule;
-pub(crate) mod run;
-pub(crate) mod run_stdin;
 pub(crate) mod show_files;
 pub(crate) mod show_settings;
