@@ -16,21 +16,22 @@ use rustc_hash::FxHashMap;
 use similar::TextDiff;
 use thiserror::Error;
 
-use ruff::linter::{lint_fix, lint_only, FixTable, FixerResult, LinterResult};
-use ruff::logging::DisplayParseError;
-use ruff::message::Message;
-use ruff::pyproject_toml::lint_pyproject_toml;
-use ruff::registry::AsRule;
-use ruff::settings::{flags, AllSettings, Settings};
-use ruff::source_kind::SourceKind;
-use ruff::{fs, IOError, SyntaxError};
 use ruff_diagnostics::Diagnostic;
+use ruff_linter::linter::{lint_fix, lint_only, FixTable, FixerResult, LinterResult};
+use ruff_linter::logging::DisplayParseError;
+use ruff_linter::message::Message;
+use ruff_linter::pyproject_toml::lint_pyproject_toml;
+use ruff_linter::registry::AsRule;
+use ruff_linter::settings::{flags, LinterSettings};
+use ruff_linter::source_kind::SourceKind;
+use ruff_linter::{fs, IOError, SyntaxError};
 use ruff_macros::CacheKey;
 use ruff_notebook::{Cell, Notebook, NotebookError, NotebookIndex};
 use ruff_python_ast::imports::ImportMap;
 use ruff_python_ast::{PySourceType, SourceType, TomlSourceType};
 use ruff_source_file::{LineIndex, SourceCode, SourceFileBuilder};
 use ruff_text_size::{TextRange, TextSize};
+use ruff_workspace::Settings;
 
 use crate::cache::Cache;
 
@@ -85,7 +86,7 @@ impl Diagnostics {
     pub(crate) fn from_source_error(
         err: &SourceExtractionError,
         path: Option<&Path>,
-        settings: &Settings,
+        settings: &LinterSettings,
     ) -> Self {
         let diagnostic = Diagnostic::from(err);
         if settings.rules.enabled(diagnostic.kind.rule()) {
@@ -143,7 +144,7 @@ impl AddAssign for Diagnostics {
 pub(crate) fn lint_path(
     path: &Path,
     package: Option<&Path>,
-    settings: &AllSettings,
+    settings: &LinterSettings,
     cache: Option<&Cache>,
     noqa: flags::Noqa,
     autofix: flags::FixMode,
@@ -178,7 +179,6 @@ pub(crate) fn lint_path(
     let source_type = match SourceType::from(path) {
         SourceType::Toml(TomlSourceType::Pyproject) => {
             let messages = if settings
-                .lib
                 .rules
                 .iter_enabled()
                 .any(|rule_code| rule_code.lint_source().is_pyproject_toml())
@@ -187,15 +187,11 @@ pub(crate) fn lint_path(
                     match std::fs::read_to_string(path).map_err(SourceExtractionError::Io) {
                         Ok(contents) => contents,
                         Err(err) => {
-                            return Ok(Diagnostics::from_source_error(
-                                &err,
-                                Some(path),
-                                &settings.lib,
-                            ));
+                            return Ok(Diagnostics::from_source_error(&err, Some(path), settings));
                         }
                     };
                 let source_file = SourceFileBuilder::new(path.to_string_lossy(), contents).finish();
-                lint_pyproject_toml(source_file, &settings.lib)
+                lint_pyproject_toml(source_file, settings)
             } else {
                 vec![]
             };
@@ -213,11 +209,7 @@ pub(crate) fn lint_path(
         Ok(Some(sources)) => sources,
         Ok(None) => return Ok(Diagnostics::default()),
         Err(err) => {
-            return Ok(Diagnostics::from_source_error(
-                &err,
-                Some(path),
-                &settings.lib,
-            ));
+            return Ok(Diagnostics::from_source_error(&err, Some(path), settings));
         }
     };
 
@@ -233,14 +225,8 @@ pub(crate) fn lint_path(
             result,
             transformed,
             fixed,
-        }) = lint_fix(
-            path,
-            package,
-            noqa,
-            &settings.lib,
-            &source_kind,
-            source_type,
-        ) {
+        }) = lint_fix(path, package, noqa, settings, &source_kind, source_type)
+        {
             if !fixed.is_empty() {
                 match autofix {
                     flags::FixMode::Apply => match transformed.as_ref() {
@@ -317,26 +303,12 @@ pub(crate) fn lint_path(
             (result, fixed)
         } else {
             // If we fail to autofix, lint the original source code.
-            let result = lint_only(
-                path,
-                package,
-                &settings.lib,
-                noqa,
-                &source_kind,
-                source_type,
-            );
+            let result = lint_only(path, package, settings, noqa, &source_kind, source_type);
             let fixed = FxHashMap::default();
             (result, fixed)
         }
     } else {
-        let result = lint_only(
-            path,
-            package,
-            &settings.lib,
-            noqa,
-            &source_kind,
-            source_type,
-        );
+        let result = lint_only(path, package, settings, noqa, &source_kind, source_type);
         let fixed = FxHashMap::default();
         (result, fixed)
     };
@@ -410,7 +382,7 @@ pub(crate) fn lint_stdin(
         Ok(Some(sources)) => sources,
         Ok(None) => return Ok(Diagnostics::default()),
         Err(err) => {
-            return Ok(Diagnostics::from_source_error(&err, path, settings));
+            return Ok(Diagnostics::from_source_error(&err, path, &settings.linter));
         }
     };
 
@@ -430,7 +402,7 @@ pub(crate) fn lint_stdin(
             path.unwrap_or_else(|| Path::new("-")),
             package,
             noqa,
-            settings,
+            &settings.linter,
             &source_kind,
             source_type,
         ) {
@@ -467,7 +439,7 @@ pub(crate) fn lint_stdin(
             let result = lint_only(
                 path.unwrap_or_else(|| Path::new("-")),
                 package,
-                settings,
+                &settings.linter,
                 noqa,
                 &source_kind,
                 source_type,
@@ -485,7 +457,7 @@ pub(crate) fn lint_stdin(
         let result = lint_only(
             path.unwrap_or_else(|| Path::new("-")),
             package,
-            settings,
+            &settings.linter,
             noqa,
             &source_kind,
             source_type,
