@@ -8,9 +8,10 @@ use anyhow::Result;
 use regex::{Captures, Regex};
 use strum::IntoEnumIterator;
 
-use ruff::registry::{Linter, Rule, RuleNamespace};
 use ruff_diagnostics::AutofixKind;
+use ruff_linter::registry::{Linter, Rule, RuleNamespace};
 use ruff_workspace::options::Options;
+use ruff_workspace::options_base::OptionsMetadata;
 
 use crate::ROOT_DIR;
 
@@ -96,14 +97,11 @@ fn process_documentation(documentation: &str, out: &mut String) {
             if let Some(rest) = line.strip_prefix("- `") {
                 let option = rest.trim_end().trim_end_matches('`');
 
-                assert!(
-                    Options::metadata().get(option).is_some(),
-                    "unknown option {option}"
-                );
+                assert!(Options::metadata().has(option), "unknown option {option}");
 
                 let anchor = option.replace('.', "-");
                 out.push_str(&format!("- [`{option}`][{option}]\n"));
-                after.push_str(&format!("[{option}]: ../../settings#{anchor}\n"));
+                after.push_str(&format!("[{option}]: ../settings.md#{anchor}\n"));
 
                 continue;
             }
@@ -151,8 +149,8 @@ Something [`else`][other].
 
 [other]: http://example.com.
 
-[task-tags]: ../../settings#task-tags
-[mccabe.max-complexity]: ../../settings#mccabe-max-complexity
+[task-tags]: ../settings.md#task-tags
+[mccabe.max-complexity]: ../settings.md#mccabe-max-complexity
 "
         );
     }
