@@ -40,6 +40,11 @@ impl<I: Idx, T> IndexSlice<I, T> {
         }
     }
 
+    #[inline]
+    pub const fn first(&self) -> Option<&T> {
+        self.raw.first()
+    }
+
     #[inline]
     pub const fn len(&self) -> usize {
         self.raw.len()
@@ -63,6 +68,13 @@ impl<I: Idx, T> IndexSlice<I, T> {
         (0..self.len()).map(|n| I::new(n))
     }
 
+    #[inline]
+    pub fn iter_enumerated(
+        &self,
+    ) -> impl DoubleEndedIterator<Item = (I, &T)> + ExactSizeIterator + '_ {
+        self.raw.iter().enumerate().map(|(n, t)| (I::new(n), t))
+    }
+
     #[inline]
     pub fn iter_mut(&mut self) -> std::slice::IterMut<'_, T> {
         self.raw.iter_mut()
