@@ -21,9 +21,9 @@ pub(crate) fn derive_impl(input: DeriveInput) -> syn::Result<proc_macro2::TokenS
     let mut parsed = Vec::new();
 
     let mut common_prefix_match_arms = quote!();
-    let mut name_match_arms = quote!(Self::Ruff => "Ruff-specific rules", Self::Numpy => "NumPy-specific rules", Self::Copyright => "Copyright-related rules", );
-    let mut url_match_arms =
-        quote!(Self::Ruff => None, Self::Numpy => None, Self::Copyright => None, );
+    let mut name_match_arms =
+        quote!(Self::Ruff => "Ruff-specific rules", Self::Numpy => "NumPy-specific rules", );
+    let mut url_match_arms = quote!(Self::Ruff => None, Self::Numpy => None, );
 
     let mut all_prefixes = HashSet::new();
 
@@ -69,7 +69,7 @@ pub(crate) fn derive_impl(input: DeriveInput) -> syn::Result<proc_macro2::TokenS
 
         let variant_ident = variant.ident;
 
-        if variant_ident != "Ruff" && variant_ident != "Numpy" && variant_ident != "Copyright" {
+        if variant_ident != "Ruff" && variant_ident != "Numpy" {
             let (name, url) = parse_doc_attr(doc_attr)?;
             name_match_arms.extend(quote! {Self::#variant_ident => #name,});
             url_match_arms.extend(quote! {Self::#variant_ident => Some(#url),});
