@@ -1,3 +1,4 @@
+use crate::helpers::map_subscript;
 use crate::{self as ast, Constant, Expr, Stmt};
 use bitflags::bitflags;
 
@@ -23,7 +24,7 @@ where
     fn add_to_names<'a>(elts: &'a [Expr], names: &mut Vec<&'a str>, flags: &mut DunderAllFlags) {
         for elt in elts {
             if let Expr::Constant(ast::ExprConstant {
-                value: Constant::Str(value),
+                value: Constant::Str(ast::StringConstant { value, .. }),
                 ..
             }) = elt
             {
@@ -63,13 +64,12 @@ where
             }
             Expr::Call(ast::ExprCall {
                 func,
-                args,
-                keywords,
+                arguments: ast::Arguments { args, keywords, .. },
                 ..
             }) => {
-                // Allow `tuple()` and `list()` calls.
+                // Allow `tuple()`, `list()`, and their generic forms, like `list[int]()`.
                 if keywords.is_empty() && args.len() <= 1 {
-                    if let Expr::Name(ast::ExprName { id, .. }) = func.as_ref() {
+                    if let Expr::Name(ast::ExprName { id, .. }) = map_subscript(func) {
                         let id = id.as_str();
                         if matches!(id, "tuple" | "list") && is_builtin(id) {
                             let [arg] = args.as_slice() else {
