@@ -1,6 +1,6 @@
 use ruff_python_ast::stmt_if::elif_else_range;
-use ruff_python_ast::Stmt;
-use ruff_python_parser::{Parse, ParseError};
+
+use ruff_python_parser::{parse_suite, ParseError};
 use ruff_text_size::TextSize;
 
 #[test]
@@ -10,8 +10,11 @@ fn extract_elif_else_range() -> Result<(), ParseError> {
 elif b:
     ...
 ";
-    let stmt = Stmt::parse(contents, "<filename>")?;
-    let stmt = Stmt::as_if_stmt(&stmt).unwrap();
+    let mut stmts = parse_suite(contents, "<filename>")?;
+    let stmt = stmts
+        .pop()
+        .and_then(ruff_python_ast::Stmt::if_stmt)
+        .unwrap();
     let range = elif_else_range(&stmt.elif_else_clauses[0], contents).unwrap();
     assert_eq!(range.start(), TextSize::from(14));
     assert_eq!(range.end(), TextSize::from(18));
@@ -21,8 +24,11 @@ elif b:
 else:
     ...
 ";
-    let stmt = Stmt::parse(contents, "<filename>")?;
-    let stmt = Stmt::as_if_stmt(&stmt).unwrap();
+    let mut stmts = parse_suite(contents, "<filename>")?;
+    let stmt = stmts
+        .pop()
+        .and_then(ruff_python_ast::Stmt::if_stmt)
+        .unwrap();
     let range = elif_else_range(&stmt.elif_else_clauses[0], contents).unwrap();
     assert_eq!(range.start(), TextSize::from(14));
     assert_eq!(range.end(), TextSize::from(18));
