@@ -56,4 +56,42 @@ selected_choices = [
 
 # Tuples with BinOp
 [i for i in (aaaaaaaaaaaaaaaaaaaaaa + bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb, ccccccccccccccccccccc)]
-[(aaaaaaaaaaaaaaaaaaaaaa + bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb, ccccccccccccccccccccc) for i in b]
\ No newline at end of file
+[(aaaaaaaaaaaaaaaaaaaaaa + bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb, ccccccccccccccccccccc) for i in b]
+
+a = [
+    aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa
+    for f in bbbbbbbbbbbbbbb
+    if f not in ccccccccccc
+]
+
+a = [
+    [1, 2, 3,]
+    for f in bbbbbbbbbbbbbbb
+    if f not in ccccccccccc
+]
+
+aaaaaaaaaaaaaaaaaaaaa = [
+    o for o in self.registry.values if o.__class__ is not ModelAdmin
+]
+
+[
+    task
+    for head_name in head_nodes
+    if (task := self.get_task_by_name(head_name))
+    if not None
+]
+
+[
+    f(x, y,)
+    for head_name in head_nodes if head_name
+]
+
+[
+    f(x, y)
+    for head_name in f(x, y,) if head_name
+]
+
+[
+    x
+    for (x, y,) in z if head_name
+]
