@@ -54,3 +54,16 @@ x = (
         c,
     ]
 ) = 1
+
+def main() -> None:
+    if True:
+        some_very_long_variable_name_abcdefghijk = some_very_long_variable_name_abcdefghijk[
+            some_very_long_variable_name_abcdefghijk.some_very_long_attribute_name
+            == "This is a very long string abcdefghijk"
+        ]
+
+        organization_application = (
+            organization_service.get_organization_applications_by_name(
+                db_request.POST["name"]
+            )
+        )[0]
