@@ -264,6 +264,7 @@ match foo:
         y = 1
 
 
+
 match foo:
     case [1, 2, *rest]:
         pass
@@ -399,3 +400,104 @@ match foo:
         b,
     }:
         pass
+
+
+match pattern_match_class:
+    case Point2D(
+            # own line
+            ):
+        ...
+
+    case (
+        Point2D
+        # own line
+        ()
+    ):
+        ...
+
+    case Point2D(  # end of line line
+            ):
+        ...
+
+    case Point2D(  # end of line
+        0, 0
+    ):
+        ...
+
+    case Point2D(0, 0):
+        ...
+
+    case Point2D(
+        (  # end of line
+        # own line
+        0
+        ), 0):
+        ...
+
+    case Point3D(x=0, y=0, z=000000000000000000000000000000000000000000000000000000000000000000000000000000000):
+        ...
+
+    case Bar(0, a=None, b="hello"):
+        ...
+
+    case FooBar(# leading
+# leading
+    # leading
+        # leading
+            0 # trailing
+# trailing
+    # trailing
+        # trailing
+            ):
+        ...
+
+    case A(
+        b # b
+        = # c
+        2 # d
+        # e
+    ):
+        pass
+
+    case A(
+        # a
+        b # b
+        = # c
+        2 # d
+        # e
+    ):
+        pass
+
+
+match pattern_match_or:
+    case ( # leading 1
+          a # trailing 1
+          # own line 1
+          | # trailing 2
+          # own line 2
+          b # trailing 3
+          # own line 3
+          | # trailing 4
+          # own line 4
+          c # trailing 5
+            ):
+        ...
+
+    case (
+        (a)
+        | # trailing
+        ( b )
+    ):
+        ...
+
+    case (a|b|c):
+        ...
+
+    case foo | bar | aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaahhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh:
+        ...
+
+    case ( # end of line
+          a | b
+    # own line
+    ):
+        ...
