@@ -1,7 +1,6 @@
 pub(crate) mod alias;
-pub(crate) mod arg;
-pub(crate) mod arg_with_default;
 pub(crate) mod arguments;
+pub(crate) mod commas;
 pub(crate) mod comprehension;
 pub(crate) mod decorator;
 pub(crate) mod elif_else_clause;
@@ -9,4 +8,7 @@ pub(crate) mod except_handler_except_handler;
 pub(crate) mod identifier;
 pub(crate) mod keyword;
 pub(crate) mod match_case;
+pub(crate) mod parameter;
+pub(crate) mod parameter_with_default;
+pub(crate) mod parameters;
 pub(crate) mod with_item;
