@@ -23,7 +23,7 @@ impl FormatNodeRule<StmtAnnAssign> for FormatStmtAnnAssign {
             f,
             [
                 target.format(),
-                text(":"),
+                token(":"),
                 space(),
                 maybe_parenthesize_expression(annotation, item, Parenthesize::IfBreaks)
             ]
@@ -34,7 +34,7 @@ impl FormatNodeRule<StmtAnnAssign> for FormatStmtAnnAssign {
                 f,
                 [
                     space(),
-                    text("="),
+                    token("="),
                     space(),
                     maybe_parenthesize_expression(value, item, Parenthesize::IfBreaks)
                 ]
