@@ -8,7 +8,7 @@ pub struct FormatStmtBreak;
 
 impl FormatNodeRule<StmtBreak> for FormatStmtBreak {
     fn fmt_fields(&self, _item: &StmtBreak, f: &mut PyFormatter) -> FormatResult<()> {
-        text("break").fmt(f)
+        token("break").fmt(f)
     }
 
     fn is_suppressed(
