@@ -15,7 +15,7 @@ impl FormatNodeRule<StmtDelete> for FormatStmtDelete {
     fn fmt_fields(&self, item: &StmtDelete, f: &mut PyFormatter) -> FormatResult<()> {
         let StmtDelete { range: _, targets } = item;
 
-        write!(f, [text("del"), space()])?;
+        write!(f, [token("del"), space()])?;
 
         match targets.as_slice() {
             [] => {
@@ -27,9 +27,9 @@ impl FormatNodeRule<StmtDelete> for FormatStmtDelete {
                         // del (
                         //     # Dangling comment
                         // )
-                        text("("),
+                        token("("),
                         block_indent(&dangling_node_comments(item)),
-                        text(")"),
+                        token(")"),
                     ]
                 )
             }
