@@ -15,18 +15,18 @@ impl FormatNodeRule<StmtGlobal> for FormatStmtGlobal {
         // move the comment "off" of the `global` statement.
         if f.context().comments().has_trailing(item.as_any_node_ref()) {
             let joined = format_with(|f| {
-                f.join_with(format_args![text(","), space()])
+                f.join_with(format_args![token(","), space()])
                     .entries(item.names.iter().formatted())
                     .finish()
             });
 
-            write!(f, [text("global"), space(), &joined])
+            write!(f, [token("global"), space(), &joined])
         } else {
             let joined = format_with(|f| {
                 f.join_with(&format_args![
-                    text(","),
+                    token(","),
                     space(),
-                    if_group_breaks(&text("\\")),
+                    if_group_breaks(&token("\\")),
                     soft_line_break(),
                 ])
                 .entries(item.names.iter().formatted())
@@ -36,10 +36,10 @@ impl FormatNodeRule<StmtGlobal> for FormatStmtGlobal {
             write!(
                 f,
                 [
-                    text("global"),
+                    token("global"),
                     space(),
                     group(&format_args!(
-                        if_group_breaks(&text("\\")),
+                        if_group_breaks(&token("\\")),
                         soft_line_break(),
                         soft_block_indent(&joined)
                     ))
