@@ -11,11 +11,11 @@ impl FormatNodeRule<StmtImport> for FormatStmtImport {
     fn fmt_fields(&self, item: &StmtImport, f: &mut PyFormatter) -> FormatResult<()> {
         let StmtImport { names, range: _ } = item;
         let names = format_with(|f| {
-            f.join_with(&format_args![text(","), space()])
+            f.join_with(&format_args![token(","), space()])
                 .entries(names.iter().formatted())
                 .finish()
         });
-        write!(f, [text("import"), space(), names])
+        write!(f, [token("import"), space(), names])
     }
 
     fn is_suppressed(
