@@ -9,6 +9,6 @@ pub struct FormatTypeParamParamSpec;
 impl FormatNodeRule<TypeParamParamSpec> for FormatTypeParamParamSpec {
     fn fmt_fields(&self, item: &TypeParamParamSpec, f: &mut PyFormatter) -> FormatResult<()> {
         let TypeParamParamSpec { range: _, name } = item;
-        write!(f, [text("**"), name.format()])
+        write!(f, [token("**"), name.format()])
     }
 }
