@@ -9,6 +9,6 @@ pub struct FormatTypeParamTypeVarTuple;
 impl FormatNodeRule<TypeParamTypeVarTuple> for FormatTypeParamTypeVarTuple {
     fn fmt_fields(&self, item: &TypeParamTypeVarTuple, f: &mut PyFormatter) -> FormatResult<()> {
         let TypeParamTypeVarTuple { range: _, name } = item;
-        write!(f, [text("*"), name.format()])
+        write!(f, [token("*"), name.format()])
     }
 }
