@@ -1,7 +1,6 @@
-use ruff_python_ast::{self as ast, Expr, Keyword};
-
 use ruff_python_ast::call_path::{collect_call_path, from_qualified_name};
-use ruff_python_ast::helpers::{find_keyword, is_const_true};
+use ruff_python_ast::helpers::is_const_true;
+use ruff_python_ast::{self as ast, Arguments, Expr, Keyword};
 
 use crate::model::SemanticModel;
 
@@ -50,7 +49,13 @@ pub fn is_logger_candidate(
     // logger names.
     if let Some(call_path) = collect_call_path(value) {
         if let Some(tail) = call_path.last() {
-            if tail.starts_with("log") || tail.ends_with("logger") || tail.ends_with("logging") {
+            if tail.starts_with("log")
+                || tail.ends_with("logger")
+                || tail.ends_with("logging")
+                || tail.starts_with("LOG")
+                || tail.ends_with("LOGGER")
+                || tail.ends_with("LOGGING")
+            {
                 return true;
             }
         }
@@ -61,8 +66,8 @@ pub fn is_logger_candidate(
 
 /// If the keywords to a  logging call contain `exc_info=True` or `exc_info=sys.exc_info()`,
 /// return the `Keyword` for `exc_info`.
-pub fn exc_info<'a>(keywords: &'a [Keyword], semantic: &SemanticModel) -> Option<&'a Keyword> {
-    let exc_info = find_keyword(keywords, "exc_info")?;
+pub fn exc_info<'a>(arguments: &'a Arguments, semantic: &SemanticModel) -> Option<&'a Keyword> {
+    let exc_info = arguments.find_keyword("exc_info")?;
 
     // Ex) `logging.error("...", exc_info=True)`
     if is_const_true(&exc_info.value) {
@@ -74,9 +79,7 @@ pub fn exc_info<'a>(keywords: &'a [Keyword], semantic: &SemanticModel) -> Option
         .value
         .as_call_expr()
         .and_then(|call| semantic.resolve_call_path(&call.func))
-        .map_or(false, |call_path| {
-            matches!(call_path.as_slice(), ["sys", "exc_info"])
-        })
+        .is_some_and(|call_path| matches!(call_path.as_slice(), ["sys", "exc_info"]))
     {
         return Some(exc_info);
     }
