@@ -143,7 +143,7 @@ pub fn to_pep604_operator(
     slice: &Expr,
     semantic: &SemanticModel,
 ) -> Option<Pep604Operator> {
-    /// Returns `true` if any argument in the slice is a quoted annotation).
+    /// Returns `true` if any argument in the slice is a quoted annotation.
     fn quoted_annotation(slice: &Expr) -> bool {
         match slice {
             Expr::Constant(ast::ExprConstant {
@@ -155,6 +155,15 @@ pub fn to_pep604_operator(
         }
     }
 
+    /// Returns `true` if any argument in the slice is a starred expression.
+    fn starred_annotation(slice: &Expr) -> bool {
+        match slice {
+            Expr::Starred(_) => true,
+            Expr::Tuple(ast::ExprTuple { elts, .. }) => elts.iter().any(starred_annotation),
+            _ => false,
+        }
+    }
+
     // If the slice is a forward reference (e.g., `Optional["Foo"]`), it can only be rewritten
     // if we're in a typing-only context.
     //
@@ -175,6 +184,14 @@ pub fn to_pep604_operator(
         }
     }
 
+    // If any of the elements are starred expressions, we can't rewrite the subscript:
+    // ```python
+    // def f(x: Union[*int, str]): ...
+    // ```
+    if starred_annotation(slice) {
+        return None;
+    }
+
     semantic
         .resolve_call_path(value)
         .as_ref()
@@ -504,3 +521,36 @@ fn find_parameter<'a>(
         .chain(parameters.kwonlyargs.iter())
         .find(|arg| arg.parameter.name.range() == binding.range())
 }
+
+/// Return the [`CallPath`] of the value to which the given [`Expr`] is assigned, if any.
+///
+/// For example, given:
+/// ```python
+/// import asyncio
+///
+/// loop = asyncio.get_running_loop()
+/// loop.create_task(...)
+/// ```
+///
+/// This function will return `["asyncio", "get_running_loop"]` for the `loop` binding.
+pub fn resolve_assignment<'a>(
+    expr: &'a Expr,
+    semantic: &'a SemanticModel<'a>,
+) -> Option<CallPath<'a>> {
+    let name = expr.as_name_expr()?;
+    let binding_id = semantic.resolve_name(name)?;
+    let statement = semantic.binding(binding_id).statement(semantic)?;
+    match statement {
+        Stmt::Assign(ast::StmtAssign { value, .. }) => {
+            let ast::ExprCall { func, .. } = value.as_call_expr()?;
+            semantic.resolve_call_path(func)
+        }
+        Stmt::AnnAssign(ast::StmtAnnAssign {
+            value: Some(value), ..
+        }) => {
+            let ast::ExprCall { func, .. } = value.as_call_expr()?;
+            semantic.resolve_call_path(func)
+        }
+        _ => None,
+    }
+}
