@@ -1107,9 +1107,38 @@ impl<'a> SemanticModel<'a> {
             .all(|(left, right)| left == right)
     }
 
-    /// Returns `true` if the given [`BindingId`] is used.
-    pub fn is_used(&self, binding_id: BindingId) -> bool {
-        self.bindings[binding_id].is_used()
+    /// Returns `true` if the given expression is an unused variable, or consists solely of
+    /// references to other unused variables. This method is conservative in that it considers a
+    /// variable to be "used" if it's shadowed by another variable with usages.
+    pub fn is_unused(&self, expr: &Expr) -> bool {
+        match expr {
+            Expr::Tuple(ast::ExprTuple { elts, .. }) => {
+                elts.iter().all(|expr| self.is_unused(expr))
+            }
+            Expr::Name(ast::ExprName { id, .. }) => {
+                // Treat a variable as used if it has any usages, _or_ it's shadowed by another variable
+                // with usages.
+                //
+                // If we don't respect shadowing, we'll incorrectly flag `bar` as unused in:
+                // ```python
+                // from random import random
+                //
+                // for bar in range(10):
+                //     if random() > 0.5:
+                //         break
+                // else:
+                //     bar = 1
+                //
+                // print(bar)
+                // ```
+                self.current_scope()
+                    .get_all(id)
+                    .map(|binding_id| self.binding(binding_id))
+                    .filter(|binding| binding.start() >= expr.start())
+                    .all(|binding| !binding.is_used())
+            }
+            _ => false,
+        }
     }
 
     /// Add a reference to the given [`BindingId`] in the local scope.
