@@ -35,9 +35,9 @@ use fs_err as fs;
 use regex::Regex;
 use ruff_python_ast::statement_visitor::{walk_body, walk_stmt, StatementVisitor};
 use ruff_python_ast::visitor::{walk_expr, Visitor};
-use ruff_python_ast::{Expr, Ranged, Stmt, Suite};
+use ruff_python_ast::{Expr, Stmt, Suite};
 use ruff_python_parser::Mode;
-use ruff_text_size::TextRange;
+use ruff_text_size::{Ranged, TextRange};
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
 use std::process::{Command, ExitCode};
