@@ -7,7 +7,7 @@ cd "$SCRIPT_DIR"
 
 cd corpus/ruff_fix_validity
 curl -L 'https://github.com/python/cpython/archive/refs/tags/v3.12.0b2.tar.gz' | tar xz
-cp -r "../../../crates/ruff/resources/test" .
+cp -r "../../../crates/ruff_linter/resources/test" .
 cd -
 cargo fuzz cmin -s none ruff_fix_validity
 
