@@ -26,44 +26,45 @@ git -C "$dir/twine" checkout 0bb428c410b8df64c04dc881ac1db37d932f3066
 if [ ! -d "$dir/django/.git" ]; then
   git clone --filter=tree:0 https://github.com/django/django "$dir/django"
 fi
-git -C "$dir/django" checkout 95e4d6b81312fdd9f8ebf3385be1c1331168b5cf
+git -C "$dir/django" checkout 48a1929ca050f1333927860ff561f6371706968a
 
 # an ML project
 if [ ! -d "$dir/transformers/.git" ]; then
   git clone --filter=tree:0 https://github.com/huggingface/transformers "$dir/transformers"
 fi
-git -C "$dir/transformers" checkout c9a82be592ca305180a7ab6a36e884bca1d426b8
+git -C "$dir/transformers" checkout 62396cff46854dc53023236cfeb785993fa70067
 
 # type annotations
 if [ ! -d "$dir/typeshed/.git" ]; then
   git clone --filter=tree:0 https://github.com/python/typeshed "$dir/typeshed"
 fi
-git -C "$dir/typeshed" checkout 7d33060e6ae3ebe54462a891f0c566c97371915b
+git -C "$dir/typeshed" checkout 2c15a8e7906e19f49bb765e2807dd0079fe9c04b
 
 # python 3.11, typing and 100% test coverage
 if [ ! -d "$dir/warehouse/.git" ]; then
   git clone --filter=tree:0 https://github.com/pypi/warehouse "$dir/warehouse"
 fi
-git -C "$dir/warehouse" checkout fe6455c0a946e81f61d72edc1049f536d8bba903
+git -C "$dir/warehouse" checkout 6be6bccf07dace18784ea8aeac7906903fdbcf3a
 
 # zulip, a django user
 if [ ! -d "$dir/zulip/.git" ]; then
   git clone --filter=tree:0 https://github.com/zulip/zulip "$dir/zulip"
 fi
-git -C "$dir/zulip" checkout 6cb080c4479546a7f5cb017fcddea56605910b48
+git -C "$dir/zulip" checkout 328cdde24331b82baa4c9b1bf1cb7b2015799826
 
 # cpython itself
 if [ ! -d "$dir/cpython/.git" ]; then
   git clone --filter=tree:0 https://github.com/python/cpython "$dir/cpython"
 fi
-git -C "$dir/cpython" checkout 45de31db9cc9be945702f3a7ca35bbb9f98476af
+git -C "$dir/cpython" checkout 1a1bfc28912a39b500c578e9f10a8a222638d411
 
 # Uncomment if you want to update the hashes
-# for i in "$dir"/*/; do git -C "$i" switch main && git -C "$i" pull && echo "# $(basename "$i") $(git -C "$i" rev-parse HEAD)"; done
+#for i in "$dir"/*/; do git -C "$i" switch main && git -C "$i" pull; done
+#for i in "$dir"/*/; do echo "# $(basename "$i") $(git -C "$i" rev-parse HEAD)"; done
 
 time cargo run --bin ruff_dev -- format-dev --stability-check \
   --error-file "$target/progress_projects_errors.txt" --log-file "$target/progress_projects_log.txt" --stats-file "$target/progress_projects_stats.txt" \
-  --files-with-errors 25 --multi-project "$dir" || (
+  --files-with-errors 16 --multi-project "$dir" || (
   echo "Ecosystem check failed"
   cat "$target/progress_projects_log.txt"
   exit 1
